==> hazelcast-jet-3.2.2-sources.jar: com/hazelcast/jet/impl/config/JetConfigSections.java <==
/*
 * Copyright (c) 2008-2019, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.jet.impl.config;

/**
 * Configuration sections for Hazelcast Jet shared by XML and YAML based
 * configurations
 */
enum JetConfigSections {
    HAZELCAST_JET("hazelcast-jet", false),
    INSTANCE("instance", false),
    IMPORT("import", true),
    PROPERTIES("properties", false),
    EDGE_DEFAULTS("edge-defaults", false),
    METRICS("metrics", false);

    final String name;
    final boolean multipleOccurrence;

    JetConfigSections(String name, boolean multipleOccurrence) {
        this.name = name;
        this.multipleOccurrence = multipleOccurrence;

    }

    static boolean canOccurMultipleTimes(String name) {
        for (JetConfigSections element : values()) {
            if (name.equals(element.name)) {
                return element.multipleOccurrence;
            }
        }
        return false;
    }

    boolean isEqual(String name) {
        return this.name.equals(name);
    }

}

==> hazelcast-jet-4.5.2-sources.jar: com/hazelcast/jet/impl/config/JetConfigSections.java <==
/*
 * Copyright (c) 2008-2021, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.jet.impl.config;

/**
 * Configuration sections for Hazelcast Jet shared by XML and YAML based
 * configurations
 */
enum JetConfigSections {
    HAZELCAST_JET("hazelcast-jet", false),
    INSTANCE("instance", false),
    IMPORT("import", true),
    PROPERTIES("properties", false),
    EDGE_DEFAULTS("edge-defaults", false);

    final String name;
    final boolean multipleOccurrence;

    JetConfigSections(String name, boolean multipleOccurrence) {
        this.name = name;
        this.multipleOccurrence = multipleOccurrence;

    }

    static boolean canOccurMultipleTimes(String name) {
        for (JetConfigSections element : values()) {
            if (name.equals(element.name)) {
                return element.multipleOccurrence;
            }
        }
        return false;
    }

    boolean isEqual(String name) {
        return this.name.equals(name);
    }

}
